@@ -1,3 +1,4 @@
+import type { JSX } from 'react';
 import { connect } from 'react-redux';
 import AutoSizer from 'react-virtualized-auto-sizer';
 
@@ -11,6 +12,7 @@ import {
   applyFieldOverrides,
   FieldConfigSource,
 } from '@grafana/data';
+import { Trans, t } from '@grafana/i18n';
 import { locationService } from '@grafana/runtime';
 import { Button, Table, Themeable2, withTheme2, UserIcon } from '@grafana/ui';
 import { TableFieldOptions, TableCellDisplayMode } from '@grafana/ui/internal';
@@ -33,6 +35,8 @@ interface State {
   dashboardUsersInfo: DashboardUsersInfoDTO | null;
 }
 
+// FIXME convert to functional component
+// eslint-disable-next-line react-prefer-function-component/react-prefer-function-component
 export class AnalyticsUsersTab extends AnalyticsTab<Props, State> {
   constructor(props: Props) {
     super(props);
@@ -60,16 +64,16 @@ export class AnalyticsUsersTab extends AnalyticsTab<Props, State> {
     } else if (diffDays < -1) {
       return date.locale('en').format('dddd');
     } else if (diffDays < 0) {
-      return 'Yesterday';
+      return t('meta-analytics.analytics-users-tab.format-date-yesterday', 'Yesterday');
     } else {
       const diffMinutes = date.diff(dateTime(), 'minutes', true);
 
       if (diffMinutes < -60) {
-        return 'Today';
+        return t('meta-analytics.analytics-users-tab.format-date-today', 'Today');
       } else if (diffMinutes < -15) {
-        return 'Last hour';
+        return t('meta-analytics.analytics-users-tab.format-date-last-hour', 'Last hour');
       } else {
-        return 'Currently viewing';
+        return t('meta-analytics.analytics-users-tab.format-date-currently-viewing', 'Currently viewing');
       }
     }
   }
@@ -82,8 +86,13 @@ export class AnalyticsUsersTab extends AnalyticsTab<Props, State> {
 
   renderUserBox(title: string, userView: UserViewDTO, styles: InsightsStyles) {
     return (
-      <div className={styles.userBox} aria-label="User information box">
-        <h6 aria-label="User box title">{title}</h6>
+      <div
+        className={styles.userBox}
+        aria-label={t('meta-analytics.analytics-users-tab.aria-label-user-information-box', 'User information box')}
+      >
+        <h6 aria-label={t('meta-analytics.analytics-users-tab.aria-label-user-box-title', 'User box title')}>
+          {title}
+        </h6>
         <UserIcon userView={userView} showTooltip={false} />
         <div className={styles.userName}>{userView.user.name}</div>
         <div>{dateTime(userView.lastActiveAt).format('YYYY-MM-DD')}</div>
@@ -104,7 +113,7 @@ export class AnalyticsUsersTab extends AnalyticsTab<Props, State> {
           return (
             <main style={{ width }}>
               {this.renderChart({
-                title: 'Views last 30 days',
+                title: t('meta-analytics.analytics-users-tab.views-last-month-title', 'Views last 30 days'),
                 fields: [
                   {
                     name: 'views',
@@ -153,8 +162,18 @@ export class AnalyticsUsersTab extends AnalyticsTab<Props, State> {
         {
           fields: [
             { name: ' ', type: FieldType.other, config: avatarFieldConfig, values: avatars },
-            { name: 'User', type: FieldType.string, config: {}, values: users },
-            { name: 'When', type: FieldType.string, config: {}, values: time },
+            {
+              name: t('meta-analytics.analytics-users-tab.user-views-data-frame-user-field', 'User'),
+              type: FieldType.string,
+              config: {},
+              values: users,
+            },
+            {
+              name: t('meta-analytics.analytics-users-tab.user-views-data-frame-when-field', 'When'),
+              type: FieldType.string,
+              config: {},
+              values: time,
+            },
           ],
           length: userViews.length,
         },
@@ -180,22 +199,46 @@ export class AnalyticsUsersTab extends AnalyticsTab<Props, State> {
       <div>
         {dailySummaries && dailySummaries.length > 0 && this.renderViewsChart()}
         <div className={styles.userBoxesContainer}>
-          {dashboardUsersInfo?.creator && this.renderUserBox('Created', dashboardUsersInfo.creator, styles)}
-          {dashboardUsersInfo?.lastEditor && this.renderUserBox('Last edited', dashboardUsersInfo.lastEditor, styles)}
-          {userViews?.length > 0 && this.renderUserBox('Last viewed', userViews[0], styles)}
+          {dashboardUsersInfo?.creator &&
+            this.renderUserBox(
+              t('meta-analytics.analytics-users-tab.created-user-box', 'Created'),
+              dashboardUsersInfo.creator,
+              styles
+            )}
+          {dashboardUsersInfo?.lastEditor &&
+            this.renderUserBox(
+              t('meta-analytics.analytics-users-tab.last-edited-user-box', 'Last edited'),
+              dashboardUsersInfo.lastEditor,
+              styles
+            )}
+          {userViews?.length > 0 &&
+            this.renderUserBox(
+              t('meta-analytics.analytics-users-tab.last-viewed-user-box', 'Last viewed'),
+              userViews[0],
+              styles
+            )}
         </div>
         {userViews?.length > 0 && (
           <div className={styles.tableContainer}>
             <div className={styles.tableHeader}>
-              <h4>Last 30 dashboard viewers</h4>
+              <h4>
+                <Trans i18nKey="meta-analytics.analytics-users-tab.last-dashboard-viewers">
+                  Last 30 dashboard viewers
+                </Trans>
+              </h4>
               {dashboard.meta.showSettings && (
                 <Button
                   icon="history"
                   variant="secondary"
                   onClick={this.onOpenVersionHistory}
-                  aria-label="Version history button"
+                  aria-label={t(
+                    'meta-analytics.analytics-users-tab.aria-label-version-history-button',
+                    'Version history button'
+                  )}
                 >
-                  Dashboard version history
+                  <Trans i18nKey="meta-analytics.analytics-users-tab.dashboard-version-history">
+                    Dashboard version history
+                  </Trans>
                 </Button>
               )}
             </div>
@@ -212,7 +255,10 @@ export class AnalyticsUsersTab extends AnalyticsTab<Props, State> {
                       data={userViewsDataFrame!}
                       height={fullTableHeight}
                       width={width}
-                      aria-label="Recent users table"
+                      aria-label={t(
+                        'meta-analytics.analytics-users-tab.aria-label-recent-users-table',
+                        'Recent users table'
+                      )}
                     />
                   </main>
                 );
